#************************************************************ 
#
# Component       CNF
#
# Synopsis        Copy files from master to vice-master
#
# Copyright 2004 Sun Microsystems, Inc. All rights reserved.
#
#
#************************************************************
#
# #ident "@(#)COPY.pm 1.1 04/03/12 SMI"
#
#************************************************************

#=head1 File copy
#
#=over 4
#
#=cut

package COPY ;

use strict;
use VAR;
use LOG;

#
# variables to be exported
#

my $G_pid;

my @G_node_id_array = ( "", "" ) ;
my @G_men_IP = ();
my $G_node_id;

#--------------------------------------------------------------
#
#  copy_one_file
#
#--------------------------------------------------------------

sub copy_one_file {

  my ($file) = @_;

  LOG::printMsg(0, "Processing %s ...", $file) ;

  # from the master: rcp <file> <vice-master>:<file>
  # from the vicemaster: rcp <master>:<file> <file>
  # from another node: rcp <master>:<file> <vice-master>:<file>
  
  # source
  my $source = "$file";
  if ($G_node_id_array[0] != $G_node_id) {
    # we are not on the master
    $source = "$G_men_IP[0]:$file";
  }

  # dest
  my $dest = "$file";
  if ($G_node_id_array[1] != $G_node_id) {
    # we are not on the vice-master
    $dest = "$G_men_IP[1]:$file";
  }
  
  # copy the file
  if (! COMMON::exec_cmd("/usr/bin/rcp $source $dest")) {
    LOG::printError("Cannot copy %s to %s", $source, $dest);
    return 0;
  }
  
  return 1 ;
}

#--------------------------------------------------------------
#
#  copy
#
#--------------------------------------------------------------

sub copy {

  my $filelistpar = "";
  ($filelistpar) = @_;
  
  my $line;
  my $filelist = "";

  $G_pid = $$ ;
  
  CONF::load_fs_conf();
  
  $G_node_id = CMM::get_local_node_id;
  COMMON::set_men_addresses(\@G_node_id_array, \@G_men_IP) ;

  # can be executed on master or vice-master only
  if (($G_node_id != $G_node_id_array[0]) 
      && ($G_node_id != $G_node_id_array[1])) {
     LOG::printError("copy only available from master or vice-master");
     return;
  }
  
  # create the list of all files by reading the data file
  # and adding the files passed as arguments
  
  if ($E_datacopy_file ne "") {
    # read the data file
    if (!open(COPYFILE, "<$E_datacopy_file")) {
      LOG::printError("error when accessing %s", $E_datacopy_file) ;
      exit 1;
    }
    
    while (<COPYFILE>) {
      chomp($line = $_) ;
      LOG::printMsg(2,"%s", $line) ;
      
      # remove comment
      $line =~ s/#.*// ;
      
      if ($line eq "") {
	next ;
      }
      
      $filelist = $filelist . " " . $line;
    }
    close(COPYFILE) ;
  }

  # add the files of the command
  if (defined($filelistpar)) {
    foreach my $file (split(' ',$filelistpar)) {
      $filelist = $filelist . " " . $file;
    }
  }

  foreach my $file (split(' ',$filelist)) {
    copy_one_file($file);
  }
}


#=back
#
#=cut

{
}

